===============================
ShowRss.info ncurses interface
===============================

.. image:: https://img.shields.io/travis/XayOn/nshowrss.svg
        :target: https://travis-ci.org/XayOn/nshowrss

.. image:: https://img.shields.io/pypi/v/nshowrss.svg
        :target: https://pypi.python.org/pypi/nshowrss


Ncurses interface for downloading showrss.info series, and keeping track of the watched / not watched episodes

* Free software: BSD license
* Documentation: https://nshowrss.readthedocs.org.

Features
--------

* NCurses interface for showrss.info using libtorrent streaming


Usage
-----

Simply pass an rss in the format provided by shorss.info to it:


::

    simpletorrentstreaming <url>
